==> hazelcast-client-protocol-1.8.0-1-sources.jar: com/hazelcast/client/impl/protocol/task/AbstractTransactionalMessageTask.java <==
/*
 * Copyright (c) 2008-2018, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.client.impl.protocol.task;

import com.hazelcast.client.impl.protocol.ClientMessage;
import com.hazelcast.instance.Node;
import com.hazelcast.nio.Connection;
import com.hazelcast.util.ThreadUtil;

public abstract class AbstractTransactionalMessageTask<P> extends AbstractCallableMessageTask<P>
        implements TransactionalMessageTask {

    public AbstractTransactionalMessageTask(ClientMessage clientMessage, Node node, Connection connection) {
        super(clientMessage, node, connection);
    }

    @Override
    protected final Object call() throws Exception {
        ThreadUtil.setThreadId(getClientThreadId());
        try {
            return innerCall();
        } finally {
            ThreadUtil.removeThreadId();
        }
    }

    protected abstract Object innerCall() throws Exception;

    protected abstract long getClientThreadId();

}

==> hazelcast-client-protocol-2.0.0-3-sources.jar: com/hazelcast/client/impl/protocol/task/AbstractTransactionalMessageTask.java <==
/*
 * Copyright (c) 2008-2019, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.client.impl.protocol.task;

import com.hazelcast.client.impl.protocol.ClientMessage;
import com.hazelcast.instance.impl.Node;
import com.hazelcast.nio.Connection;
import com.hazelcast.util.ThreadUtil;

public abstract class AbstractTransactionalMessageTask<P> extends AbstractCallableMessageTask<P>
        implements TransactionalMessageTask {

    public AbstractTransactionalMessageTask(ClientMessage clientMessage, Node node, Connection connection) {
        super(clientMessage, node, connection);
    }

    @Override
    protected final Object call() throws Exception {
        ThreadUtil.setThreadId(getClientThreadId());
        try {
            return innerCall();
        } finally {
            ThreadUtil.removeThreadId();
        }
    }

    protected abstract Object innerCall() throws Exception;

    protected abstract long getClientThreadId();

}
